Module arcm
sovran_
arc
0.1.5
Module arcm
Module Items
Structs
In crate sovran_
arc
sovran_arc
Module
arcm
Structs

Arcm
A wrapper combining Arc and Mutex for convenient shared mutable access Only works with types that implement Clone
Weak
Arcm
A weak reference wrapper for Arcm